Reference Files
===============

The ``cube_build`` step uses two reference files: CUBEPAR and RESOL.
CUBEPAR is used for both NIRSpec and MIRI IFU data.
The RESOL reference file is only used for processing MIRI IFU data and uses an
experimental weighting option that is still in the testing phase.


.. include:: ../references_general/cubepar_reffile.inc

.. include:: ../references_general/resol_reffile.inc
